==> tika_1.5.orig.tar.xz: tika-1.5/tika-parsers/src/test/java/org/apache/tika/parser/crypto/Pkcs7ParserTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tika.parser.crypto;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.io.InputStream;

import org.apache.tika.TikaTest;
import org.apache.tika.exception.TikaException;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.parser.ParseContext;
import org.apache.tika.sax.BodyContentHandler;
import org.xml.sax.ContentHandler;

public class Pkcs7ParserTest extends TikaTest {
    public void testDetachedSignature() throws Exception {
        InputStream input = Pkcs7ParserTest.class.getResourceAsStream(
                "/test-documents/testDetached.p7s");
        try {
            ContentHandler handler = new BodyContentHandler();
            Metadata metadata = new Metadata();
            new Pkcs7Parser().parse(input, handler, metadata, new ParseContext());
        } catch (NullPointerException npe) {
            fail("should not get NPE");
        } catch (TikaException te) {
            assertTrue(te.toString().indexOf("cannot parse detached pkcs7 signature") != -1);
        } finally {
            input.close();
        }
    }
}

==> tika_1.22.orig.tar.xz: tika-1.22/tika-parsers/src/test/java/org/apache/tika/parser/crypto/Pkcs7ParserTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tika.parser.crypto;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.io.InputStream;

import org.apache.tika.TikaTest;
import org.apache.tika.exception.TikaException;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.parser.ParseContext;
import org.apache.tika.sax.BodyContentHandler;
import org.xml.sax.ContentHandler;

public class Pkcs7ParserTest extends TikaTest {
    public void testDetachedSignature() throws Exception {
        try (InputStream input = Pkcs7ParserTest.class.getResourceAsStream(
                "/test-documents/testDetached.p7s")) {
            ContentHandler handler = new BodyContentHandler();
            Metadata metadata = new Metadata();
            new Pkcs7Parser().parse(input, handler, metadata, new ParseContext());
        } catch (NullPointerException npe) {
            fail("should not get NPE");
        } catch (TikaException te) {
            assertTrue(te.toString().contains("cannot parse detached pkcs7 signature"));
        }
    }
}
